cli

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: MIT Imports: 23 Imported by: 0

Documentation

Overview

Package cli implements the certree command-line interface.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(stdout io.Writer, stderr io.Writer, args []string, version string) exitCode

Run is the testable entry point for the certree CLI. It accepts writers and args for testability and returns an exit code instead of calling os.Exit.

Types

This section is empty.

Jump to